pub enum AutomodCommand {
Start {
parameter: Parameter,
allow_list: Option<Vec<ParticipantId>>,
playlist: Option<Vec<ParticipantId>>,
},
Edit {
allow_list: Option<Vec<ParticipantId>>,
playlist: Option<Vec<ParticipantId>>,
},
Stop,
Select(Select),
Yield {
next: Option<ParticipantId>,
},
}Expand description
Commands received by the automod module
Variants
Start
Start the auto-moderation with a provided config
Fields
allow_list: Option<Vec<ParticipantId>>Depending on the selection strategy, the list of Participant that can be chosen from.
-
Strategy =
none,randomornomination: The allow_list acts as pool of participants which can be selected (by nomination or randomly etc). -
Strategy =
playlistThe allow_list does not get used by this strategy.
playlist: Option<Vec<ParticipantId>>Ordered list of queued participants
-
Strategy =
none,randomornomination: The playlist does not get used by these strategies. -
Strategy =
playlistThe playlist is a ordered list of participants which will get used to select the next participant when yielding. It is also used as a pool to select participants randomly from (moderator commandSelect).
Edit
Set either the allow_list or playlist or both
Fields
allow_list: Option<Vec<ParticipantId>>Edit the allow_list. If None, it should not be edited.
playlist: Option<Vec<ParticipantId>>Edit the playlist. If None, it should not be edited.
Stop
Stop the auto-moderation
Select(Select)
Select a user to be active speaker
Yield
User yields it’s speaker status
Fields
next: Option<ParticipantId>In some cases a user must select the next participant to be speaker
Implementations
Sourceimpl AutomodCommand
impl AutomodCommand
Sourcepub fn requires_moderator_privileges(&self) -> bool
pub fn requires_moderator_privileges(&self) -> bool
Returns if the issued command requires the participant to be a moderator