ExcalidrawCommand

Enum ExcalidrawCommand 

pub enum ExcalidrawCommand {
    Start {
        initial_scene: Value,
        edit_restrictions: EditRestrictions,
    },
    Stop,
    BroadcastVolatile {
        data: Value,
    },
    Broadcast {
        data: Value,
    },
    StoreScene {
        scene: Value,
    },
    Follow {
        participant_id: ParticipantId,
    },
    Unfollow {
        participant_id: ParticipantId,
    },
    EnableEditRestrictions {
        unrestricted_participants: HashSet<ParticipantId>,
    },
    DisableEditRestrictions,
}

Variants



Start

Start a excalidraw session

Fields

initial_scene: Value

The initial scene of excalidraw

edit_restrictions: EditRestrictions


Stop

Stop the excalidraw session and discard the current state



BroadcastVolatile

Broadcast arbitrary excalidraw data to all participants in the room. This data is volatile, i.e. it must not change the excalidraw state. E.g., update the mouse position of the sender.

Fields

data: Value

Arbitrary excalidraw data



Broadcast

Broadcast arbitrary excalidraw data to all participants in the room. This data can modify the excalidraw state for all participants, however it is not persisted server-side. To persist the excalidraw state server side, use ExcalidrawCommand::StoreScene.

Fields

data: Value

Arbitrary excalidraw data



StoreScene

Persists the scene server-side.

Fields

scene: Value

The scene to be stored



Follow

Fields

participant_id: ParticipantId

The id of the participant to follow



Unfollow

Fields

participant_id: ParticipantId

The id of the participant to unfollow



EnableEditRestrictions

Enables the edit restriction state, where only a subset of participants are allowed to edit excalidraw. Moderators are always allowed to edit excalidraw.

Fields

unrestricted_participants: HashSet<ParticipantId>

The list of participants that are still allowed to edit



DisableEditRestrictions

Disables the edit restriction state, all participants are allowed to edit excalidraw.