pub enum LegalVoteCommand {
Start(UserParameters),
Stop {
legal_vote_id: LegalVoteId,
},
Cancel {
legal_vote_id: LegalVoteId,
reason: CustomCancelReason,
},
Vote {
legal_vote_id: LegalVoteId,
option: VoteOption,
token: Token,
},
ReportIssue {
legal_vote_id: LegalVoteId,
issue: Issue,
},
GeneratePdf {
legal_vote_id: LegalVoteId,
timezone: Option<TimeZone>,
},
}Expand description
An incoming message issued by an participant.
Variants
Start(UserParameters)
Start a new vote.
Stop
Stop a vote and show results to the participants.
Fields

legal_vote_id: LegalVoteIdThe vote id of the targeted vote.
Cancel
Cancel a vote.
Fields

legal_vote_id: LegalVoteIdThe vote id of the targeted vote.

reason: CustomCancelReasonThe reason for the cancel.
Vote
Vote for an item on a vote.
Fields

legal_vote_id: LegalVoteIdThe vote id of the targeted vote.

option: VoteOptionThe chosen vote option.
ReportIssue
Report an issue to the vote creator.
Fields

legal_vote_id: LegalVoteIdThe identifier of the affected vote.
GeneratePdf
Generate a PDF from a passed vote.
Fields

legal_vote_id: LegalVoteIdThe identifier of the targeted vote.

timezone: Option<TimeZone>An optional timezone for the PDF generation. Defaults to UTC. The timezone should be in a format standardized by IANA (e.g., “CET” or “Europe/Vienna”). For more details, visit: https://www.iana.org/time-zones.