pub enum ModerationCommand {
Show 14 variants
Kick {
target: ParticipantId,
},
Ban {
target: ParticipantId,
},
Unban {
target: ParticipantId,
},
UpdateRole {
participant_id: ParticipantId,
new_role: Role,
},
Debrief(KickScope),
ChangeWaitingRoomState {
new_state: WaitingRoom,
},
SendToWaitingRoom {
target: ParticipantId,
},
ChangeDisplayName {
new_name: DisplayName,
target: ParticipantId,
},
EnableDisplayNameChangeRestrictions {
unrestricted_participants: HashSet<ParticipantId>,
},
DisableDisplayNameChangeRestrictions,
Accept {
target: ParticipantId,
},
Mute {
participants: BTreeSet<ParticipantId>,
},
EnableMicrophoneRestrictions {
unrestricted_participants: BTreeSet<ParticipantId>,
},
DisableMicrophoneRestrictions,
}Expand description
Commands for the moderation namespace
Variants
Kick
Kick a participant from the room
Fields
target: ParticipantIdBan
Ban a participant from the room
Fields
target: ParticipantIdUnban
Unban a banned participant
Fields
target: ParticipantIdUpdateRole
Change the role of a participant
Fields
participant_id: ParticipantIdThe affected participant
Debrief(KickScope)
Start the debriefing
ChangeWaitingRoomState
Set the state of the waiting room
Fields
new_state: WaitingRoomThe new state of the waiting room
SendToWaitingRoom
Send a participant to the waiting room
Fields
target: ParticipantIdThe participant to move to the waiting room
ChangeDisplayName
Change the display name of the targeted guest
Fields
new_name: DisplayNameThe new display name
target: ParticipantIdThe participant that will have their name changed
EnableDisplayNameChangeRestrictions
Enables the display name restriction state where only the participants that are part of the
unrestricted_participants are allowed to change their own display name. Moderators are
always allowed to change display names.
Fields
unrestricted_participants: HashSet<ParticipantId>DisableDisplayNameChangeRestrictions
Disables the display name restriction state which will allow all participants to change their own display name again.
Accept
Accept a participant from the waiting room into the meeting
Fields
target: ParticipantIdThe participant to accept into the meeting
Mute
Mutes participants
Fields
participants: BTreeSet<ParticipantId>The participants that should get muted
EnableMicrophoneRestrictions
Enables the microphone restriction state where only the participants that are part of the
unrestricted_participants are allowed to unmute themselves. This will mute all
participants who are not allowed to unmute themselves, but are currently not muted.
Fields
unrestricted_participants: BTreeSet<ParticipantId>Participants that are still allowed to unmute
DisableMicrophoneRestrictions
Disable the microphone restriction state which will allow all participants to unmute their microphone again.